@@ -1,12 +1,17 @@
 from __future__ import annotations
 
-from wexample_config.const.types import DictConfig
-from wexample_filestate.const.disk import DiskItemType
-from wexample_helpers.const.types import FileStringOrPath
-from wexample_helpers.helpers.file import file_resolve_path
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from wexample_config.const.types import DictConfig
+    from wexample_filestate.const.disk import DiskItemType
+    from wexample_helpers.const.types import FileStringOrPath
 
 
 def config_has_same_type_as_path(config: DictConfig, path: FileStringOrPath) -> bool:
+    from wexample_filestate.const.disk import DiskItemType
+    from wexample_helpers.helpers.file import file_resolve_path
+
     resolved_path = file_resolve_path(path)
 
     if resolved_path.is_file() and config_is_item_type(config, DiskItemType.FILE):
