@@ -1,16 +1,21 @@
 from __future__ import annotations
 
-from typing import ClassVar
+from typing import TYPE_CHECKING, ClassVar
 
 from wexample_filestate.item.file.structured_content_file import StructuredContentFile
-from wexample_helpers.const.types import JsonContent, StructuredData
+from wexample_helpers.const.types import StructuredData
+
+if TYPE_CHECKING:
+    from wexample_helpers.const.types import JsonContent, StructuredData
 
 
 class JsonFile(StructuredContentFile):
     EXTENSION_JSON: ClassVar[str] = "json"
 
-    def _expected_file_name_extension(self) -> str:
-        return self.EXTENSION_JSON
+    def dumps(self, content: StructuredData | None) -> str:
+        import json
+
+        return json.dumps(content or {}, ensure_ascii=False, indent=2)
 
     # ---------- Parsing / Serialization ----------
     def loads(self, text: str, strict: bool = False) -> JsonContent:  # type: ignore[name-defined]
@@ -23,7 +28,5 @@ class JsonFile(StructuredContentFile):
                 raise e
             return {}
 
-    def dumps(self, content: StructuredData | None) -> str:
-        import json
-
-        return json.dumps(content or {}, ensure_ascii=False, indent=2)
+    def _expected_file_name_extension(self) -> str:
+        return self.EXTENSION_JSON
