@@ -2,13 +2,15 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from pydantic import BaseModel
+from wexample_helpers.classes.base_class import BaseClass
+from wexample_helpers.decorator.base_class import base_class
 
 if TYPE_CHECKING:
     from wexample_filestate.operation.abstract_operation import AbstractOperation
 
 
-class AbstractOperationsProvider(BaseModel):
+@base_class
+class AbstractOperationsProvider(BaseClass):
     @staticmethod
     def get_operations() -> list[type[AbstractOperation]]:
         return []
