@@ -2,25 +2,28 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, ClassVar
 
-from wexample_config.const.types import DictConfig
-from wexample_filestate.config_option.text_filter_config_option import (
-    TextFilterConfigOption,
-)
-from wexample_filestate.const.disk import DiskItemType
+from wexample_helpers.classes.base_class import BaseClass
+from wexample_helpers.decorator.base_class import base_class
 
 if TYPE_CHECKING:
+    from wexample_config.const.types import DictConfig
     from wexample_filestate.config_value.readme_content_config_value import (
         ReadmeContentConfigValue,
     )
 
 
-class WithReadmeWorkdirMixin:
+@base_class
+class WithReadmeWorkdirMixin(BaseClass):
     README_FILENAME: ClassVar[str] = "README.md"
 
     def append_readme(self, config: DictConfig | None = None) -> DictConfig:
+        from wexample_filestate.option.text_filter_option import (
+            TextFilterOption,
+        )
         from wexample_filestate.config_value.readme_content_config_value import (
             ReadmeContentConfigValue,
         )
+        from wexample_filestate.const.disk import DiskItemType
 
         config.get("children").append(
             {
@@ -31,7 +34,7 @@ class WithReadmeWorkdirMixin:
                 "default_content": ReadmeContentConfigValue(
                     templates=[], parameters={}
                 ),
-                "text_filter": [TextFilterConfigOption.OPTION_NAME_ENSURE_NEWLINE],
+                "text_filter": [TextFilterOption.OPTION_NAME_ENSURE_NEWLINE],
             }
         )
 
@@ -42,4 +45,4 @@ class WithReadmeWorkdirMixin:
             ReadmeContentConfigValue,
         )
 
-        return ReadmeContentConfigValue()
+        return ReadmeContentConfigValue(templates=[], parameters={})
