@@ -6,15 +6,15 @@ from wexample_filestate.testing.test_abstract_operation import TestAbstractOpera
 
 
 class TestShouldExistConfigOption(TestAbstractOperation):
+    def _operation_get_count(self) -> int:
+        return 0
+
     def _operation_test_setup_configuration(self) -> Any | None:
-        from wexample_filestate.config_option.should_exist_config_option import (
-            ShouldExistConfigOption,
+        from wexample_filestate.option.should_exist_option import (
+            ShouldExistOption,
         )
 
         return {
             # Simply test this configuration format.
-            ShouldExistConfigOption
+            ShouldExistOption
         }
-
-    def _operation_get_count(self) -> int:
-        return 0
